@@ -49,9 +49,9 @@ class Paddle():
         self.vendors_v2 = 'https://vendors.paddle.com/api/2.0/'
         self.default_url = self.vendors_v2
 
-        self.vendor_id: int = vendor_id
-        self.api_key: str = api_key
-        self.json: dict = {
+        self.vendor_id = vendor_id
+        self.api_key = api_key
+        self.json = {
             'vendor_id': self.vendor_id,
             'vendor_auth_code': self.api_key,
         }
@@ -71,7 +71,7 @@ class Paddle():
         data: dict = None,
         json: dict = None
     ) -> dict:
-        kwargs: dict = {}
+        kwargs = {}
 
         # URL join will remove anything after the host name is the url
         # is prepended with a /
@@ -110,16 +110,18 @@ class Paddle():
         except requests.HTTPError as e:  # pragma: no cover - Unsure how to trigger a HTTPError here  # NOQA: E501
             raise PaddleException(e)
 
-        response_json: dict = response.json()
+        response_json = response.json()
         if 'error' in response_json:
             raise PaddleException(response_json['error'])
         # API v1 does not include success
         if 'success' in response_json and not response_json['success']:  # pragma: no cover - Not sure if this is even possible  # NOQA: E501
             raise PaddleException(response_json)
 
-        if 'response' in response_json:
+        if 'response' in response_json and response_json['response'] is not None:  # NOQA: E501
             return response_json['response']
-        return response_json
+
+        # Response is only {"success": True}
+        return response_json['success']
 
     def get(self, url, **kwargs):
         kwargs['url'] = url
@@ -157,5 +159,6 @@ class Paddle():
     from ._plans import create_plan
 
     from ._subscription_users import list_subscription_users
+    from ._subscription_users import cancel_subscription
 
     from ._webhooks import get_webhook_history
